Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(749)

Unified Diff: third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp
diff --git a/third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp b/third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp
index c5dc7be173f2a58f309cc59df6cf155732299e37..c9ff36d459462301029ee95e5f76cd5e72163ef2 100644
--- a/third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp
+++ b/third_party/WebKit/Source/core/paint/SVGContainerPainter.cpp
@@ -23,9 +23,9 @@ void SVGContainerPainter::paint(const PaintInfo& paintInfo) {
return;
FloatRect boundingBox =
- m_layoutSVGContainer.paintInvalidationRectInLocalSVGCoordinates();
- // LayoutSVGHiddenContainer's paint invalidation rect is always empty but we
- // need to paint its descendants.
+ m_layoutSVGContainer.visualRectInLocalSVGCoordinates();
+ // LayoutSVGHiddenContainer's visual rect is always empty but we need to
+ // paint its descendants.
if (!m_layoutSVGContainer.isSVGHiddenContainer() &&
!paintInfo.cullRect().intersectsCullRect(
m_layoutSVGContainer.localToSVGParentTransform(), boundingBox))
« no previous file with comments | « third_party/WebKit/Source/core/paint/SVGClipPainter.cpp ('k') | third_party/WebKit/Source/core/paint/SVGImagePainter.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698